Struct ModelMetadata
pub struct ModelMetadata { /* private fields */ }Expand description
Builder for handwritten model metadata.
Use ModelMetadata to declare the public names that should be attached to
a handwritten equation. After validation, the resulting metadata can be
attached to handwritten crate::ODE, crate::Analytical, and
crate::SDE models through their with_metadata(...) methods.
Implementations
impl ModelMetadata
impl ModelMetadata
pub fn new(name: impl Into<String>) -> ModelMetadata
pub fn new(name: impl Into<String>) -> ModelMetadata
Create a new metadata builder with a model name.
pub fn kind(self, kind: ModelKind) -> ModelMetadata
pub fn kind(self, kind: ModelKind) -> ModelMetadata
Set the model kind explicitly.
pub fn parameters<I, S>(self, parameters: I) -> ModelMetadata
pub fn parameters<I, S>(self, parameters: I) -> ModelMetadata
Replace the ordered parameter list.
pub fn covariates<I>(self, covariates: I) -> ModelMetadatawhere
I: IntoIterator<Item = Covariate>,
pub fn covariates<I>(self, covariates: I) -> ModelMetadatawhere
I: IntoIterator<Item = Covariate>,
Replace the ordered covariate list.
pub fn states<I, S>(self, states: I) -> ModelMetadata
pub fn states<I, S>(self, states: I) -> ModelMetadata
Replace the ordered state list.
pub fn route(self, route: Route) -> ModelMetadata
pub fn route(self, route: Route) -> ModelMetadata
Add one route declaration.
pub fn routes<I>(self, routes: I) -> ModelMetadatawhere
I: IntoIterator<Item = Route>,
pub fn routes<I>(self, routes: I) -> ModelMetadatawhere
I: IntoIterator<Item = Route>,
Extend with multiple route declarations.
pub fn outputs<I, S>(self, outputs: I) -> ModelMetadata
pub fn outputs<I, S>(self, outputs: I) -> ModelMetadata
Replace the ordered output list.
pub fn particles(self, particles: usize) -> ModelMetadata
pub fn particles(self, particles: usize) -> ModelMetadata
Set the particle count for stochastic models.
pub fn analytical_kernel(self, analytical: AnalyticalKernel) -> ModelMetadata
pub fn analytical_kernel(self, analytical: AnalyticalKernel) -> ModelMetadata
Set the analytical kernel identity for built-in analytical models.
pub fn parameters_decl(&self) -> &[Parameter]
pub fn parameters_decl(&self) -> &[Parameter]
Get the ordered parameter metadata.
pub fn covariates_decl(&self) -> &[Covariate]
pub fn covariates_decl(&self) -> &[Covariate]
Get the ordered covariate metadata.
pub fn states_decl(&self) -> &[State]
pub fn states_decl(&self) -> &[State]
Get the ordered state metadata.
pub fn routes_decl(&self) -> &[Route]
pub fn routes_decl(&self) -> &[Route]
Get the ordered route metadata.
pub fn outputs_decl(&self) -> &[Output]
pub fn outputs_decl(&self) -> &[Output]
Get the ordered output metadata.
pub fn particles_decl(&self) -> Option<usize>
pub fn particles_decl(&self) -> Option<usize>
Get the declared particle count.
pub fn analytical_kernel_decl(&self) -> Option<AnalyticalKernel>
pub fn analytical_kernel_decl(&self) -> Option<AnalyticalKernel>
Get the declared analytical kernel identity.
pub fn validate(self) -> Result<ValidatedModelMetadata, ModelMetadataError>
pub fn validate(self) -> Result<ValidatedModelMetadata, ModelMetadataError>
Validate this metadata using its declared kind.
Use this when the metadata itself already declares whether the model is ODE, analytical, or SDE.
pub fn validate_for(
self,
kind: ModelKind,
) -> Result<ValidatedModelMetadata, ModelMetadataError>
pub fn validate_for( self, kind: ModelKind, ) -> Result<ValidatedModelMetadata, ModelMetadataError>
Validate this metadata for a specific model kind.
Use this when the equation type determines the model family and you want validation to enforce that family explicitly.
pub fn validate_for_with_particles(
self,
kind: ModelKind,
fallback_particles: usize,
) -> Result<ValidatedModelMetadata, ModelMetadataError>
pub fn validate_for_with_particles( self, kind: ModelKind, fallback_particles: usize, ) -> Result<ValidatedModelMetadata, ModelMetadataError>
Validate this metadata for a specific model kind, using a fallback particle count when the metadata itself does not declare one.